@@ -5,23 +5,23 @@
 if "--help" ∈ ARGS
     println(
         """
-docs/make.jl
+        docs/make.jl
 
-Render the `Manifolds.jl` documentation with optional arguments
+        Render the `Manifolds.jl` documentation with optional arguments
 
-Arguments
-* `--exclude-tutorials` - exclude the tutorials from the menu of Documenter,
-  This can be used if not all tutorials are rendered and you want to therefore exclude links
-  to these, especially the corresponding menu. This option should not be set on CI.
-  Locally this is also set if `--quarto` is not set and not all tutorials are rendered.
-* `--help`              - print this help and exit without rendering the documentation
-* `--prettyurls`        – toggle the pretty urls part to true, which is always set on CI
-* `--quarto`            – (re)run the Quarto notebooks from the `tutorials/` folder before
-  generating the documentation. If they are generated once they are cached accordingly.
-  Then you can spare time in the rendering by not passing this argument.
-  If quarto is not run, some tutorials are generated as empty files, since they
-  are referenced from within the documentation.
-""",
+        Arguments
+        * `--exclude-tutorials` - exclude the tutorials from the menu of Documenter,
+          This can be used if not all tutorials are rendered and you want to therefore exclude links
+          to these, especially the corresponding menu. This option should not be set on CI.
+          Locally this is also set if `--quarto` is not set and not all tutorials are rendered.
+        * `--help`              - print this help and exit without rendering the documentation
+        * `--prettyurls`        – toggle the pretty urls part to true, which is always set on CI
+        * `--quarto`            – (re)run the Quarto notebooks from the `tutorials/` folder before
+          generating the documentation. If they are generated once they are cached accordingly.
+          Then you can spare time in the rendering by not passing this argument.
+          If quarto is not run, some tutorials are generated as empty files, since they
+          are referenced from within the documentation.
+        """,
     )
     exit(0)
 end
@@ -34,13 +34,13 @@ tutorials_in_menu = !("--exclude-tutorials" ∈ ARGS)
 # (a) setup the tutorials menu – check whether all files exist
 tutorials_menu =
     "How to..." => [
-        "🚀 Get Started with `Manifolds.jl`" => "tutorials/getstarted.md",
-        "work in charts" => "tutorials/working-in-charts.md",
-        "perform Hand gesture analysis" => "tutorials/hand-gestures.md",
-        "integrate on manifolds and handle probability densities" => "tutorials/integration.md",
-        "explore curvature without coordinates" => "tutorials/exploring-curvature.md",
-        "work with groups" => "tutorials/groups.md",
-    ]
+    "🚀 Get Started with `Manifolds.jl`" => "tutorials/getstarted.md",
+    "work in charts" => "tutorials/working-in-charts.md",
+    "work with a metric defined in a chart" => "tutorials/work-with-a-metric-defined-in-a-chart.md",
+    "perform Hand gesture analysis" => "tutorials/hand-gestures.md",
+    "integrate on manifolds and handle probability densities" => "tutorials/integration.md",
+    "explore curvature without coordinates" => "tutorials/exploring-curvature.md",
+]
 # Check whether all tutorials are rendered, issue a warning if not (and quarto if not set)
 all_tutorials_exist = true
 for (name, file) in tutorials_menu.second
@@ -76,28 +76,19 @@ end
 if Base.active_project() != joinpath(@__DIR__, "Project.toml")
     using Pkg
     Pkg.activate(@__DIR__)
-    Pkg.develop(PackageSpec(; path=(@__DIR__) * "/../"))
-    Pkg.resolve()
     Pkg.instantiate()
 end
 
 # (c) If quarto is set, or we are on CI, run quarto
 if run_quarto || run_on_CI
-    using CondaPkg
-    CondaPkg.withenv() do
-        @info "Rendering Quarto"
-        tutorials_folder = (@__DIR__) * "/../tutorials"
-        # instantiate the tutorials environment if necessary
-        Pkg.activate(tutorials_folder)
-        # For a breaking release -> also set the tutorials folder to the most recent version
-        Pkg.develop(PackageSpec(; path=(@__DIR__) * "/../"))
-        Pkg.resolve()
-        Pkg.instantiate()
-        Pkg.build("IJulia") # build `IJulia` to the right version.
-        Pkg.activate(@__DIR__) # but return to the docs one before
-        run(`quarto render $(tutorials_folder)`)
-        return nothing
-    end
+    @info "Rendering Quarto"
+    tutorials_folder = (@__DIR__) * "/../tutorials"
+    # instantiate the tutorials environment if necessary
+    Pkg.activate(tutorials_folder)
+    # For a breaking release -> also set the tutorials folder to the most recent version
+    Pkg.instantiate()
+    Pkg.activate(@__DIR__) # but return to the docs one before
+    run(`quarto render $(tutorials_folder)`)
 end
 
 # (d) load necessary packages for the docs
@@ -111,6 +102,22 @@ using Test, FiniteDifferences
 ENV["GKSwstype"] = "100"
 
 # (e) add CONTRIBUTING.md and NEWS.md to docs
+
+function add_links(line::String, url::String = "https://github.com/JuliaManifolds/Manifolds.jl")
+    # replace issues (#XXXX) -> ([#XXXX](url/issue/XXXX))
+    while (m = match(r"\(\#([0-9]+)\)", line)) !== nothing
+        id = m.captures[1]
+        line = replace(line, m.match => "([#$id]($url/issues/$id))")
+    end
+    # replace ## [X.Y.Z] -> with a link to the release [X.Y.Z](url/releases/tag/vX.Y.Z)
+    while (m = match(r"\#\# \[([0-9]+.[0-9]+.[0-9]+)\] (.*)", line)) !== nothing
+        tag = m.captures[1]
+        date = m.captures[2]
+        line = replace(line, m.match => "## [$tag]($url/releases/tag/v$tag) ($date)")
+    end
+    return line
+end
+
 generated_path = joinpath(@__DIR__, "src", "misc")
 base_url = "https://github.com/JuliaManifolds/Manifolds.jl/blob/master/"
 isdir(generated_path) || mkdir(generated_path)
@@ -127,49 +134,44 @@ for fname in ["CONTRIBUTING.md", "NEWS.md"]
         )
         # Write the contents out below the meta block
         for line in eachline(joinpath(dirname(@__DIR__), fname))
-            println(io, line)
+            println(io, add_links(line))
         end
     end
 end
 
 # (f) final step: render the docs
-bib = CitationBibliography(joinpath(@__DIR__, "src", "references.bib"); style=:alpha)
+bib = CitationBibliography(joinpath(@__DIR__, "src", "references.bib"); style = :alpha)
 links = InterLinks(
     "ManifoldsBase" => ("https://juliamanifolds.github.io/ManifoldsBase.jl/stable/"),
 )
+
 modules = [
     Manifolds,
-    isdefined(Base, :get_extension) ?
-    Base.get_extension(Manifolds, :ManifoldsBoundaryValueDiffEqExt) :
-    Manifolds.ManifoldsBoundaryValueDiffEqExt,
-    isdefined(Base, :get_extension) ?
-    Base.get_extension(Manifolds, :ManifoldsNLsolveExt) : Manifolds.ManifoldsNLsolveExt,
-    isdefined(Base, :get_extension) ?
-    Base.get_extension(Manifolds, :ManifoldsOrdinaryDiffEqDiffEqCallbacksExt) :
-    Manifolds.ManifoldsOrdinaryDiffEqDiffEqCallbacksExt,
-    isdefined(Base, :get_extension) ?
-    Base.get_extension(Manifolds, :ManifoldsOrdinaryDiffEqExt) :
-    Manifolds.ManifoldsOrdinaryDiffEqExt,
-    isdefined(Base, :get_extension) ?
-    Base.get_extension(Manifolds, :ManifoldsRecipesBaseExt) :
-    Manifolds.ManifoldsRecipesBaseExt,
-    isdefined(Base, :get_extension) ? Base.get_extension(Manifolds, :ManifoldsTestExt) :
-    Manifolds.ManifoldsTestExt,
+    Base.get_extension(Manifolds, :ManifoldsBoundaryValueDiffEqExt),
+    Base.get_extension(Manifolds, :ManifoldsNLsolveExt),
+    Base.get_extension(Manifolds, :ManifoldsOrdinaryDiffEqDiffEqCallbacksExt),
+    Base.get_extension(Manifolds, :ManifoldsOrdinaryDiffEqExt),
+    Base.get_extension(Manifolds, :ManifoldsRecipesBaseExt),
+    Base.get_extension(Manifolds, :ManifoldsTestExt),
+    Manifolds.Test,
 ]
-if modules isa Vector{Union{Nothing,Module}}
+
+if modules isa Vector{Union{Nothing, Module}}
     error("At least one module has not been properly loaded: ", modules)
 end
+
 makedocs(;
-    format=Documenter.HTML(
-        prettyurls=(get(ENV, "CI", nothing) == "true") || ("--prettyurls" ∈ ARGS),
-        assets=["assets/favicon.ico", "assets/citations.css", "assets/link-icons.css"],
-        size_threshold_warn=200 * 2^10, # raise slightly from 100 to 200 KiB
-        size_threshold=300 * 2^10,      # raise slightly 200 to 300 KiB
+    format = Documenter.HTML(
+        prettyurls = (get(ENV, "CI", nothing) == "true") || ("--prettyurls" ∈ ARGS),
+        assets = ["assets/favicon.ico", "assets/citations.css", "assets/link-icons.css"],
+        search_size_threshold_warn = 1000 * 2^10, # raise slightly from 500 to 1 MiB
+        size_threshold_warn = 200 * 2^10, # raise slightly from 100 to 200 KiB
+        size_threshold = 300 * 2^10,      # raise slightly 200 to 300 KiB
     ),
-    modules=modules,
-    authors="Seth Axen, Mateusz Baran, Ronny Bergmann, and contributors.",
-    sitename="Manifolds.jl",
-    pages=[
+    modules = modules,
+    authors = "Seth Axen, Mateusz Baran, Ronny Bergmann, and contributors.",
+    sitename = "Manifolds.jl",
+    pages = [
         "Home" => "index.md",
         (tutorials_in_menu ? [tutorials_menu] : [])...,
         "Manifolds" => [
@@ -228,19 +230,15 @@ makedocs(;
             ],
             "Manifold decorators" => [
                 "Connection manifold" => "manifolds/connection.md",
-                "Group manifold" => "manifolds/group.md",
                 "Metric manifold" => "manifolds/metric.md",
-                "Quotient manifold" => "manifolds/quotient.md",
             ],
         ],
         "Features on Manifolds" => [
             "Atlases and charts" => "features/atlases.md",
             "Differentiation" => "features/differentiation.md",
             "Distributions" => "features/distributions.md",
-            "Group actions" => "features/group_actions.md",
             "Integration" => "features/integration.md",
             "Statistics" => "features/statistics.md",
-            "Testing" => "features/testing.md",
             "Utilities" => "features/utilities.md",
         ],
         "Miscellanea" => [
@@ -248,11 +246,13 @@ makedocs(;
             "Changelog" => "misc/NEWS.md",
             "Contributing" => "misc/CONTRIBUTING.md",
             "Internals" => "misc/internals.md",
+            "Test suite" => "misc/testsuite.md",
             "Notation" => "misc/notation.md",
             "References" => "misc/references.md",
         ],
     ],
-    plugins=[bib, links],
-    warnonly=[:missing_docs],
+    plugins = [bib, links],
 )
-deploydocs(repo="github.com/JuliaManifolds/Manifolds.jl.git", push_preview=true)
+deploydocs(repo = "github.com/JuliaManifolds/Manifolds.jl.git", push_preview = true)
+#back to main env
+Pkg.activate()
