@@ -15,17 +15,13 @@ where the field ``𝔽 ∈ \{ ℝ, ℂ\}``.
 
 Generate the manifold of ``n×n`` invertible matrices.
 """
-struct InvertibleMatrices{𝔽,T} <: AbstractDecoratorManifold{𝔽}
+struct InvertibleMatrices{𝔽, T} <: AbstractDecoratorManifold{𝔽}
     size::T
 end
 
-function InvertibleMatrices(n::Int, field::AbstractNumbers=ℝ; parameter::Symbol=:type)
+function InvertibleMatrices(n::Int, field::AbstractNumbers = ℝ; parameter::Symbol = :type)
     size = wrap_type_parameter(parameter, (n,))
-    return InvertibleMatrices{field,typeof(size)}(size)
-end
-
-function active_traits(f, ::InvertibleMatrices, args...)
-    return merge_traits(IsEmbeddedSubmanifold())
+    return InvertibleMatrices{field, typeof(size)}(size)
 end
 
 @doc raw"""
@@ -60,49 +56,53 @@ embed(::InvertibleMatrices, p) = p
 embed(::InvertibleMatrices, p, X) = X
 
 function get_coordinates(
-    ::InvertibleMatrices{ℝ,<:Any},
-    p,
-    X,
-    ::DefaultOrthonormalBasis{ℝ,TangentSpaceType},
-)
+        ::InvertibleMatrices{ℝ, <:Any},
+        p,
+        X,
+        ::DefaultOrthonormalBasis{ℝ, TangentSpaceType},
+    )
     return vec(X)
 end
 
 function get_coordinates!(
-    ::InvertibleMatrices{ℝ,<:Any},
-    Xⁱ,
-    p,
-    X,
-    ::DefaultOrthonormalBasis{ℝ,TangentSpaceType},
-)
+        ::InvertibleMatrices{ℝ, <:Any},
+        Xⁱ,
+        p,
+        X,
+        ::DefaultOrthonormalBasis{ℝ, TangentSpaceType},
+    )
     return copyto!(Xⁱ, X)
 end
 
-function get_embedding(::InvertibleMatrices{𝔽,TypeParameter{Tuple{n}}}) where {n,𝔽}
-    return Euclidean(n, n; field=𝔽)
+function get_embedding(::InvertibleMatrices{𝔽, TypeParameter{Tuple{n}}}) where {n, 𝔽}
+    return Euclidean(n, n; field = 𝔽)
 end
-function get_embedding(M::InvertibleMatrices{𝔽,Tuple{Int}}) where {𝔽}
+function get_embedding(M::InvertibleMatrices{𝔽, Tuple{Int}}) where {𝔽}
     n = get_parameter(M.size)[1]
-    return Euclidean(n, n; field=𝔽, parameter=:field)
+    return Euclidean(n, n; field = 𝔽, parameter = :field)
+end
+
+function ManifoldsBase.get_embedding_type(::InvertibleMatrices)
+    return ManifoldsBase.EmbeddedSubmanifoldType()
 end
 
 function get_vector(
-    M::InvertibleMatrices{ℝ,<:Any},
-    p,
-    Xⁱ,
-    ::DefaultOrthonormalBasis{ℝ,TangentSpaceType},
-)
+        M::InvertibleMatrices{ℝ, <:Any},
+        p,
+        Xⁱ,
+        ::DefaultOrthonormalBasis{ℝ, TangentSpaceType},
+    )
     n = get_parameter(M.size)[1]
     return reshape(Xⁱ, n, n)
 end
 
 function get_vector!(
-    ::InvertibleMatrices{ℝ,<:Any},
-    X,
-    p,
-    Xⁱ,
-    ::DefaultOrthonormalBasis{ℝ,TangentSpaceType},
-)
+        ::InvertibleMatrices{ℝ, <:Any},
+        X,
+        p,
+        Xⁱ,
+        ::DefaultOrthonormalBasis{ℝ, TangentSpaceType},
+    )
     return copyto!(X, Xⁱ)
 end
 
@@ -119,7 +119,7 @@ is_flat(M::InvertibleMatrices) = true
 Return the dimension of the [`InvertibleMatrices`](@ref) matrix `M` over the number system
 `𝔽`, which is the same dimension as its embedding, the [`Euclidean`](@ref)`(n, n; field=𝔽)`.
 """
-function manifold_dimension(M::InvertibleMatrices{<:Any,𝔽}) where {𝔽}
+function manifold_dimension(M::InvertibleMatrices{<:Any, 𝔽}) where {𝔽}
     return manifold_dimension(get_embedding(M))
 end
 
@@ -136,12 +136,12 @@ embedding.
 rand(M::InvertibleMatrices; kwargs...)
 
 function Random.rand!(
-    rng::AbstractRNG,
-    M::InvertibleMatrices,
-    pX;
-    vector_at=nothing,
-    kwargs...,
-)
+        rng::AbstractRNG,
+        M::InvertibleMatrices,
+        pX;
+        vector_at = nothing,
+        kwargs...,
+    )
     rand!(rng, get_embedding(M), pX; kwargs...)
     if vector_at === nothing # for points ensure invertibility
         _ensure_nonzero_rng_determinant!(rng, get_embedding(M), pX; kwargs...)
@@ -149,10 +149,10 @@ function Random.rand!(
     return pX
 end
 
-function Base.show(io::IO, ::InvertibleMatrices{𝔽,TypeParameter{Tuple{n}}}) where {n,𝔽}
+function Base.show(io::IO, ::InvertibleMatrices{𝔽, TypeParameter{Tuple{n}}}) where {n, 𝔽}
     return print(io, "InvertibleMatrices($(n), $(𝔽))")
 end
-function Base.show(io::IO, M::InvertibleMatrices{𝔽,Tuple{Int}}) where {𝔽}
+function Base.show(io::IO, M::InvertibleMatrices{𝔽, Tuple{Int}}) where {𝔽}
     n = get_parameter(M.size)[1]
     return print(io, "InvertibleMatrices($(n), $(𝔽); parameter=:field)")
 end
