@@ -1,8 +1,3 @@
-
-function active_traits(f, ::ProductManifold, args...)
-    return merge_traits(IsDefaultMetric(ProductMetric()))
-end
-
 function allocate_coordinates(::ProductManifold, p, T, n::Int)
     return allocate(submanifold_component(p, 1), T, n)
 end
@@ -21,6 +16,8 @@ function adjoint_Jacobi_field!(M::ProductManifold, Y, p, q, t, X, β::Tβ) where
     return Y
 end
 
+metric(::ProductManifold) = ProductMetric()
+
 @doc raw"""
     flat(M::ProductManifold, p, X::FVector{TangentSpaceType})
 
