@@ -7,7 +7,7 @@ in the embedding.
 abstract type AbstractProjectiveSpace{𝔽} <: AbstractDecoratorManifold{𝔽} end
 
 @doc raw"""
-    ProjectiveSpace{n,𝔽} <: AbstractProjectiveSpace{𝔽}
+    ProjectiveSpace{𝔽, n} <: AbstractProjectiveSpace{𝔽}
 
 The projective space ``𝔽ℙ^n`` is the manifold of all lines in ``𝔽^{n+1}``.
 The default representation is in the embedding, i.e. as unit norm vectors in
@@ -37,20 +37,16 @@ Generate the projective space ``𝔽ℙ^{n} ⊂ 𝔽^{n+1}``, defaulting to the
 ``ℝℙ^n``, where `field` can also be used to generate the complex- and right-quaternionic
 projective spaces.
 """
-struct ProjectiveSpace{T,𝔽} <: AbstractProjectiveSpace{𝔽}
+struct ProjectiveSpace{𝔽, T} <: AbstractProjectiveSpace{𝔽}
     size::T
 end
-function ProjectiveSpace(n::Int, field::AbstractNumbers=ℝ; parameter::Symbol=:type)
+function ProjectiveSpace(n::Int, field::AbstractNumbers = ℝ; parameter::Symbol = :type)
     size = wrap_type_parameter(parameter, (n,))
-    return ProjectiveSpace{typeof(size),field}(size)
-end
-
-function active_traits(f, ::AbstractProjectiveSpace, args...)
-    return merge_traits(IsIsometricEmbeddedManifold())
+    return ProjectiveSpace{field, typeof(size)}(size)
 end
 
 @doc raw"""
-    ArrayProjectiveSpace{T<:Tuple,𝔽} <: AbstractProjectiveSpace{𝔽}
+    ArrayProjectiveSpace{𝔽, T<:Tuple} <: AbstractProjectiveSpace{𝔽}
 
 The projective space ``𝔽ℙ^{n₁,n₂,…,nᵢ}`` is the manifold of all lines in ``𝔽^{n₁,n₂,…,nᵢ}``.
 The default representation is in the embedding, i.e. as unit (Frobenius) norm matrices in
@@ -85,16 +81,16 @@ Generate the projective space ``𝔽ℙ^{n_1, n_2, …, n_i}``, defaulting to th
 space, where `field` can also be used to generate the complex- and right-quaternionic
 projective spaces.
 """
-struct ArrayProjectiveSpace{T,𝔽} <: AbstractProjectiveSpace{𝔽}
+struct ArrayProjectiveSpace{𝔽, T} <: AbstractProjectiveSpace{𝔽}
     size::T
 end
 function ArrayProjectiveSpace(
-    n::Vararg{Int,I};
-    field::AbstractNumbers=ℝ,
-    parameter::Symbol=:type,
-) where {I}
+        n::Vararg{Int, I};
+        field::AbstractNumbers = ℝ,
+        parameter::Symbol = :type,
+    ) where {I}
     size = wrap_type_parameter(parameter, n)
-    return ArrayProjectiveSpace{typeof(size),field}(size)
+    return ArrayProjectiveSpace{field, typeof(size)}(size)
 end
 
 function allocation_promotion_function(::AbstractProjectiveSpace{ℂ}, f, args::Tuple)
@@ -127,31 +123,35 @@ tangent space of the embedding and that the Frobenius inner product
 ``⟨p, X⟩_{\mathrm{F}} = 0``.
 """
 function check_vector(
-    M::AbstractProjectiveSpace,
-    p,
-    X::T;
-    atol::Real=sqrt(prod(representation_size(M))) * eps(real(float(number_eltype(T)))),
-    kwargs...,
-) where {T}
-    if !isapprox(dot(p, X), 0; atol=atol, kwargs...)
+        M::AbstractProjectiveSpace,
+        p,
+        X::T;
+        atol::Real = sqrt(prod(representation_size(M))) * eps(real(float(number_eltype(T)))),
+        kwargs...,
+    ) where {T}
+    if !isapprox(dot(p, X), 0; atol = atol, kwargs...)
         return DomainError(
             dot(p, X),
             "The vector $(X) is not a tangent vector to $(p) on $(M), since it is not" *
-            " orthogonal in the embedding.",
+                " orthogonal in the embedding.",
         )
     end
     return nothing
 end
 
 function decorated_manifold(M::AbstractProjectiveSpace{𝔽}) where {𝔽}
-    return Euclidean(representation_size(M)...; field=𝔽)
+    return Euclidean(representation_size(M)...; field = 𝔽)
 end
-function decorated_manifold(M::ProjectiveSpace{<:Tuple,𝔽}) where {𝔽}
-    return Euclidean(representation_size(M)...; field=𝔽, parameter=:field)
+function decorated_manifold(M::ProjectiveSpace{𝔽, <:Tuple}) where {𝔽}
+    return Euclidean(representation_size(M)...; field = 𝔽, parameter = :field)
 end
 
 get_embedding(M::AbstractProjectiveSpace) = decorated_manifold(M)
 
+function ManifoldsBase.get_embedding_type(::AbstractProjectiveSpace)
+    return ManifoldsBase.IsometricallyEmbeddedManifoldType()
+end
+
 embed(::AbstractProjectiveSpace, p) = p
 embed(::AbstractProjectiveSpace, p, X) = X
 
@@ -185,7 +185,7 @@ function exp!(M::AbstractProjectiveSpace, q, p, X)
     return q
 end
 
-function get_basis(M::ProjectiveSpace{<:Any,ℝ}, p, B::DiagonalizingOrthonormalBasis{ℝ})
+function get_basis(M::ProjectiveSpace{ℝ}, p, B::DiagonalizingOrthonormalBasis{ℝ})
     n = get_parameter(M.size)[1]
     return get_basis(Sphere(n), p, B)
 end
@@ -221,22 +221,22 @@ function get_coordinates_orthonormal!(M::AbstractProjectiveSpace{ℝ}, c, p, X,
     return _gc_impl!(c, p, X, n)
 end
 function get_coordinates_orthonormal!(
-    M::AbstractProjectiveSpace{ℂ},
-    c,
-    p,
-    X,
-    ::ComplexNumbers,
-)
+        M::AbstractProjectiveSpace{ℂ},
+        c,
+        p,
+        X,
+        ::ComplexNumbers,
+    )
     n = div(manifold_dimension(M), 2)
     return _gc_impl!(c, p, X, n)
 end
 function get_coordinates_orthonormal!(
-    M::AbstractProjectiveSpace{ℍ},
-    c,
-    p,
-    X,
-    ::QuaternionNumbers,
-)
+        M::AbstractProjectiveSpace{ℍ},
+        c,
+        p,
+        X,
+        ::QuaternionNumbers,
+    )
     n = div(manifold_dimension(M), 4)
     return _gc_impl!(c, p, X, n)
 end
@@ -278,12 +278,12 @@ function get_vector_orthonormal!(M::AbstractProjectiveSpace{ℂ}, Y, p, X, ::Com
     return _gv_impl!(Y, p, X, n)
 end
 function get_vector_orthonormal!(
-    M::AbstractProjectiveSpace{ℍ},
-    Y,
-    p,
-    X,
-    ::QuaternionNumbers,
-)
+        M::AbstractProjectiveSpace{ℍ},
+        Y,
+        p,
+        X,
+        ::QuaternionNumbers,
+    )
     n = div(manifold_dimension(M), 4)
     return _gv_impl!(Y, p, X, n)
 end
@@ -316,7 +316,7 @@ inverse_retract(
     ::AbstractProjectiveSpace,
     p,
     q,
-    ::Union{ProjectionInverseRetraction,PolarInverseRetraction,QRInverseRetraction},
+    ::Union{ProjectionInverseRetraction, PolarInverseRetraction, QRInverseRetraction},
 )
 
 function inverse_retract_qr!(::AbstractProjectiveSpace, X, p, q)
@@ -503,7 +503,7 @@ retract(
     ::AbstractProjectiveSpace,
     p,
     X,
-    ::Union{ProjectionRetraction,PolarRetraction,QRRetraction},
+    ::Union{ProjectionRetraction, PolarRetraction, QRRetraction},
 )
 
 function ManifoldsBase.retract_polar!(M::AbstractProjectiveSpace, q, p, X)
@@ -521,12 +521,12 @@ function ManifoldsBase.retract_project!(M::AbstractProjectiveSpace, q, p, X)
 end
 
 function ManifoldsBase.retract_project_fused!(
-    M::AbstractProjectiveSpace,
-    q,
-    p,
-    X,
-    t::Number,
-)
+        M::AbstractProjectiveSpace,
+        q,
+        p,
+        X,
+        t::Number,
+    )
     q .= p .+ t .* X
     return project!(M, q, q)
 end
@@ -540,17 +540,17 @@ function ManifoldsBase.retract_qr_fused!(M::AbstractProjectiveSpace, q, p, X, t:
     return project!(M, q, q)
 end
 
-function Base.show(io::IO, ::ProjectiveSpace{TypeParameter{Tuple{n}},𝔽}) where {n,𝔽}
+function Base.show(io::IO, ::ProjectiveSpace{𝔽, TypeParameter{Tuple{n}}}) where {n, 𝔽}
     return print(io, "ProjectiveSpace($(n), $(𝔽))")
 end
-function Base.show(io::IO, M::ProjectiveSpace{Tuple{Int},𝔽}) where {𝔽}
+function Base.show(io::IO, M::ProjectiveSpace{𝔽, Tuple{Int}}) where {𝔽}
     n = get_parameter(M.size)[1]
     return print(io, "ProjectiveSpace($(n), $(𝔽); parameter=:field)")
 end
-function Base.show(io::IO, ::ArrayProjectiveSpace{TypeParameter{tn},𝔽}) where {tn<:Tuple,𝔽}
+function Base.show(io::IO, ::ArrayProjectiveSpace{𝔽, TypeParameter{tn}}) where {tn <: Tuple, 𝔽}
     return print(io, "ArrayProjectiveSpace($(join(tn.parameters, ", ")); field=$(𝔽))")
 end
-function Base.show(io::IO, M::ArrayProjectiveSpace{<:Tuple,𝔽}) where {𝔽}
+function Base.show(io::IO, M::ArrayProjectiveSpace{𝔽, <:Tuple}) where {𝔽}
     n = M.size
     return print(io, "ArrayProjectiveSpace($(join(n, ", ")); field=$(𝔽), parameter=:field)")
 end
@@ -599,9 +599,11 @@ end
 Parallel transport a vector `X` from the tangent space at a point `p` on the
 [`AbstractProjectiveSpace`](@ref) `M` along the [`geodesic`](@extref `ManifoldsBase.geodesic-Tuple{AbstractManifold, Any, Any}`) in the direction
 indicated by the tangent vector `d`, i.e.
+
 ````math
 \mathcal{P}_{\exp_p (d) ← p}(X) = X - \left(p \frac{\sin θ}{θ} + d \frac{1 - \cos θ}{θ^2}\right) ⟨d, X⟩_p,
 ````
+
 where ``θ = \lVert d \rVert``, and ``⟨⋅, ⋅⟩_p`` is the [`inner`](@ref) product at the point ``p``.
 For the real projective space, this is equivalent to the same vector transport on the real
 [`AbstractSphere`](@ref).
