@@ -1,5 +1,5 @@
 @doc raw"""
-    Stiefel{T,𝔽} <: AbstractDecoratorManifold{𝔽}
+    Stiefel{𝔽, T} <: AbstractDecoratorManifold{𝔽}
 
 The Stiefel manifold consists of all ``n×k``, ``n ≥ k`` unitary matrices, i.e.
 
@@ -19,7 +19,7 @@ T_p \mathcal M = \{ X ∈ 𝔽^{n×k} : p^{\mathrm{H}}X + X^{\mathrm{H}}p = 0_k\
 
 where ``0_k`` is the ``k×k`` zero matrix.
 
-This manifold is modeled as an embedded manifold to the [`Euclidean`](@ref), i.e.
+This manifold is modelled as an embedded manifold to the [`Euclidean`](@ref), i.e.
 several functions like the [`inner`](@ref inner(::Euclidean, ::Any...)) product and the
 [`zero_vector`](@ref zero_vector(::Euclidean, ::Any...)) are inherited from the embedding.
 
@@ -31,20 +31,16 @@ The manifold is named after
 
 Generate the (real-valued) Stiefel manifold of ``n×k`` dimensional orthonormal matrices.
 """
-struct Stiefel{T,𝔽} <: AbstractDecoratorManifold{𝔽}
+struct Stiefel{𝔽, T} <: AbstractDecoratorManifold{𝔽}
     size::T
 end
 
-function Stiefel(n::Int, k::Int, field::AbstractNumbers=ℝ; parameter::Symbol=:type)
+function Stiefel(n::Int, k::Int, field::AbstractNumbers = ℝ; parameter::Symbol = :type)
     size = wrap_type_parameter(parameter, (n, k))
-    return Stiefel{typeof(size),field}(size)
+    return Stiefel{field, typeof(size)}(size)
 end
 
-function active_traits(f, ::Stiefel, args...)
-    return merge_traits(IsIsometricEmbeddedManifold(), IsDefaultMetric(EuclideanMetric()))
-end
-
-function allocation_promotion_function(::Stiefel{<:Any,ℂ}, ::Any, ::Tuple)
+function allocation_promotion_function(::Stiefel{ℂ}, ::Any, ::Tuple)
     return complex
 end
 
@@ -123,6 +119,8 @@ Return [`PolarInverseRetraction`](@extref `ManifoldsBase.PolarInverseRetraction`
 """
 default_inverse_retraction_method(::Stiefel) = PolarInverseRetraction()
 
+metric(::Stiefel) = EuclideanMetric()
+
 """
     default_retraction_method(M::Stiefel)
 
@@ -143,12 +141,16 @@ end
 embed(::Stiefel, p) = p
 embed(::Stiefel, p, X) = X
 
-function get_embedding(::Stiefel{TypeParameter{Tuple{n,k}},𝔽}) where {n,k,𝔽}
-    return Euclidean(n, k; field=𝔽)
+function get_embedding(::Stiefel{𝔽, TypeParameter{Tuple{n, k}}}) where {n, k, 𝔽}
+    return Euclidean(n, k; field = 𝔽)
 end
-function get_embedding(M::Stiefel{Tuple{Int,Int},𝔽}) where {𝔽}
+function get_embedding(M::Stiefel{𝔽, Tuple{Int, Int}}) where {𝔽}
     n, k = get_parameter(M.size)
-    return Euclidean(n, k; field=𝔽, parameter=:field)
+    return Euclidean(n, k; field = 𝔽, parameter = :field)
+end
+
+function ManifoldsBase.get_embedding_type(::Stiefel)
+    return ManifoldsBase.IsometricallyEmbeddedManifoldType()
 end
 
 @doc raw"""
@@ -199,26 +201,26 @@ function _stiefel_inv_retr_qr_mul_by_r_generic!(M::Stiefel, X, q, R, A)
 end
 
 function _stiefel_inv_retr_qr_mul_by_r!(
-    ::Stiefel{TypeParameter{Tuple{n,1}}},
-    X,
-    q,
-    A,
-    ::Type,
-) where {n}
-    @inbounds R = SMatrix{1,1}(inv(A[1, 1]))
+        ::Stiefel{𝔽, TypeParameter{Tuple{n, 1}}},
+        X,
+        q,
+        A,
+        ::Type,
+    ) where {𝔽, n}
+    @inbounds R = SMatrix{1, 1}(inv(A[1, 1]))
     return mul!(X, q, R)
 end
 function _stiefel_inv_retr_qr_mul_by_r!(
-    M::Stiefel{TypeParameter{Tuple{n,1}}},
-    X,
-    q,
-    A::StaticArray,
-    ::Type{ElT},
-) where {n,ElT}
+        M::Stiefel{𝔽, TypeParameter{Tuple{n, 1}}},
+        X,
+        q,
+        A::StaticArray,
+        ::Type{ElT},
+    ) where {𝔽, n, ElT}
     return invoke(
         _stiefel_inv_retr_qr_mul_by_r!,
         Tuple{
-            Stiefel{TypeParameter{Tuple{n,1}}},
+            Stiefel{𝔽, TypeParameter{Tuple{n, 1}}},
             typeof(X),
             typeof(q),
             AbstractArray,
@@ -232,12 +234,12 @@ function _stiefel_inv_retr_qr_mul_by_r!(
     )
 end
 function _stiefel_inv_retr_qr_mul_by_r!(
-    ::Stiefel{TypeParameter{Tuple{n,2}}},
-    X,
-    q,
-    A,
-    ::Type{ElT},
-) where {n,ElT}
+        ::Stiefel{𝔽, TypeParameter{Tuple{n, 2}}},
+        X,
+        q,
+        A,
+        ::Type{ElT},
+    ) where {𝔽, n, ElT}
     R11 = inv(A[1, 1])
     @inbounds R =
         hcat(SA[R11, zero(ElT)], A[SOneTo(2), SOneTo(2)] \ SA[-R11 * A[2, 1], one(ElT)])
@@ -247,16 +249,16 @@ function _stiefel_inv_retr_qr_mul_by_r!(
     return mul!(X, q, R)
 end
 function _stiefel_inv_retr_qr_mul_by_r!(
-    M::Stiefel{TypeParameter{Tuple{n,2}}},
-    X,
-    q,
-    A::StaticArray,
-    ::Type{ElT},
-) where {n,ElT}
+        M::Stiefel{𝔽, TypeParameter{Tuple{n, 2}}},
+        X,
+        q,
+        A::StaticArray,
+        ::Type{ElT},
+    ) where {𝔽, n, ElT}
     return invoke(
         _stiefel_inv_retr_qr_mul_by_r!,
         Tuple{
-            Stiefel{TypeParameter{Tuple{n,2}}},
+            Stiefel{𝔽, TypeParameter{Tuple{n, 2}}},
             typeof(X),
             typeof(q),
             AbstractArray,
@@ -270,13 +272,13 @@ function _stiefel_inv_retr_qr_mul_by_r!(
     )
 end
 function _stiefel_inv_retr_qr_mul_by_r!(
-    M::Stiefel{TypeParameter{Tuple{n,k}}},
-    X,
-    q,
-    A::StaticArray,
-    ::Type{ElT},
-) where {n,k,ElT}
-    R = zeros(MMatrix{k,k,ElT})
+        M::Stiefel{𝔽, TypeParameter{Tuple{n, k}}},
+        X,
+        q,
+        A::StaticArray,
+        ::Type{ElT},
+    ) where {𝔽, n, k, ElT}
+    R = zeros(MMatrix{k, k, ElT})
     return _stiefel_inv_retr_qr_mul_by_r_generic!(M, X, q, R, A)
 end
 function _stiefel_inv_retr_qr_mul_by_r!(M::Stiefel, X, q, A, ::Type{ElT}) where {ElT}
@@ -303,8 +305,8 @@ function inverse_retract_qr!(M::Stiefel, X, p, q)
     return X
 end
 
-function _isapprox(M::Stiefel, p, X, Y; atol=sqrt(max_eps(X, Y)), kwargs...)
-    return isapprox(norm(M, p, X - Y), 0; atol=atol, kwargs...)
+function _isapprox(M::Stiefel, p, X, Y; atol = sqrt(max_eps(X, Y)), kwargs...)
+    return isapprox(norm(M, p, X - Y), 0; atol = atol, kwargs...)
 end
 
 """
@@ -328,15 +330,15 @@ The dimension is given by
 \end{aligned}
 ````
 """
-function manifold_dimension(M::Stiefel{<:Any,ℝ})
+function manifold_dimension(M::Stiefel{ℝ})
     n, k = get_parameter(M.size)
     return n * k - div(k * (k + 1), 2)
 end
-function manifold_dimension(M::Stiefel{<:Any,ℂ})
+function manifold_dimension(M::Stiefel{ℂ})
     n, k = get_parameter(M.size)
     return 2 * n * k - k * k
 end
-function manifold_dimension(M::Stiefel{<:Any,ℍ})
+function manifold_dimension(M::Stiefel{ℍ})
     n, k = get_parameter(M.size)
     return 4 * n * k - k * (2k - 1)
 end
@@ -353,15 +355,15 @@ When `vector_at` is not `nothing`, return a (Gaussian) random vector from the ta
 ``T_{vector\_at}\mathrm{St}(n,k)`` with mean zero and standard deviation `σ` by projecting a
 random Matrix onto the tangent vector at `vector_at`.
 """
-rand(::Stiefel; σ::Real=1.0)
+rand(::Stiefel; σ::Real = 1.0)
 
 function Random.rand!(
-    rng::AbstractRNG,
-    M::Stiefel{<:Any,𝔽},
-    pX;
-    vector_at=nothing,
-    σ::Real=one(real(eltype(pX))),
-) where {𝔽}
+        rng::AbstractRNG,
+        M::Stiefel{𝔽},
+        pX;
+        vector_at = nothing,
+        σ::Real = one(real(eltype(pX))),
+    ) where {𝔽}
     n, k = get_parameter(M.size)
     if vector_at === nothing
         A = σ * randn(rng, 𝔽 === ℝ ? Float64 : ComplexF64, n, k)
@@ -475,13 +477,13 @@ function ManifoldsBase.retract_pade!(M::Stiefel, q, p, X, m::PadeRetraction)
 end
 
 function ManifoldsBase.retract_pade_fused!(
-    ::Stiefel,
-    q,
-    p,
-    X,
-    t::Number,
-    ::PadeRetraction{m},
-) where {m}
+        ::Stiefel,
+        q,
+        p,
+        X,
+        t::Number,
+        ::PadeRetraction{m},
+    ) where {m}
     tX = t * X
     Pp = I - 1 // 2 * p * p'
     WpX = Pp * tX * p' - p * tX' * Pp
@@ -532,10 +534,10 @@ i.e. `(n,k)`, which is the matrix dimensions.
 """
 representation_size(M::Stiefel) = get_parameter(M.size)
 
-function Base.show(io::IO, ::Stiefel{TypeParameter{Tuple{n,k}},𝔽}) where {n,k,𝔽}
+function Base.show(io::IO, ::Stiefel{𝔽, TypeParameter{Tuple{n, k}}}) where {n, k, 𝔽}
     return print(io, "Stiefel($(n), $(k), $(𝔽))")
 end
-function Base.show(io::IO, M::Stiefel{Tuple{Int,Int},𝔽}) where {𝔽}
+function Base.show(io::IO, M::Stiefel{𝔽, Tuple{Int, Int}}) where {𝔽}
     n, k = get_parameter(M.size)
     return print(io, "Stiefel($(n), $(k), $(𝔽); parameter=:field)")
 end
