@@ -58,7 +58,7 @@ end
     distance(M::MetricManifold{SymmetricPositiveDefinite,AffineInvariantMetric}, p, q)
 
 Compute the distance on the [`SymmetricPositiveDefinite`](@ref) manifold between `p` and `q`,
-as a [`MetricManifold`](@ref) with [`AffineInvariantMetric`](@ref). The formula reads
+as a [`MetricManifold`](@extref ManifoldsBase.MetricManifold) with [`AffineInvariantMetric`](@ref). The formula reads
 
 ```math
 d_{\mathcal P(n)}(p,q)
@@ -83,7 +83,7 @@ end
     exp(M::MetricManifold{<:SymmetricPositiveDefinite,AffineInvariantMetric}, p, X)
 
 Compute the exponential map from `p` with tangent vector `X` on the
-[`SymmetricPositiveDefinite`](@ref) `M` with its default [`MetricManifold`](@ref) having the
+[`SymmetricPositiveDefinite`](@ref) `M` with its default [`MetricManifold`](@extref ManifoldsBase.MetricManifold) having the
 [`AffineInvariantMetric`](@ref). The formula reads
 
 ```math
@@ -103,9 +103,9 @@ function exp(::SymmetricPositiveDefinite, p::SPDPoint, X)
     pUe = p_sqrt * Ue
     q = SPDPoint(
         pUe * Se * transpose(pUe),
-        store_p=!ismissing(p.p),
-        store_sqrt=!ismissing(p.sqrt),
-        store_sqrt_inv=!ismissing(p.sqrt_inv),
+        store_p = !ismissing(p.p),
+        store_sqrt = !ismissing(p.sqrt),
+        store_sqrt_inv = !ismissing(p.sqrt_inv),
     )
     return q
 end
@@ -149,7 +149,7 @@ end
 
 Return a orthonormal basis `Ξ` as a vector of tangent vectors (of length
 [`manifold_dimension`](@ref) of `M`) in the tangent space of `p` on the
-[`MetricManifold`](@ref) of [`SymmetricPositiveDefinite`](@ref) manifold `M` with
+[`MetricManifold`](@extref ManifoldsBase.MetricManifold) of [`SymmetricPositiveDefinite`](@ref) manifold `M` with
 [`AffineInvariantMetric`](@ref) that diagonalizes the curvature tensor ``R(u,v)w``
 with eigenvalues `κ` and where the direction `B.frame_direction` ``V`` has curvature `0`.
 
@@ -157,19 +157,19 @@ The construction is based on an ONB for the symmetric matrices similar to [`get_
 just that the ONB here is build from the eigen vectors of ``p^{\frac{1}{2}}Vp^{\frac{1}{2}}``.
 """
 function get_basis_diagonalizing(
-    M::SymmetricPositiveDefinite,
-    p,
-    B::DiagonalizingOrthonormalBasis,
-)
+        M::SymmetricPositiveDefinite,
+        p,
+        B::DiagonalizingOrthonormalBasis,
+    )
     N = get_parameter(M.size)[1]
     (p_sqrt, p_sqrt_inv) = spd_sqrt_and_sqrt_inv(p)
     eigv = eigen(Symmetric(p_sqrt_inv * B.frame_direction * p_sqrt_inv))
     V = eigv.vectors
     Ξ = [
         (i == j ? 1 / 2 : 1 / sqrt(2)) *
-        p_sqrt *
-        (V[:, i] * transpose(V[:, j]) + V[:, j] * transpose(V[:, i])) *
-        p_sqrt for i in 1:N for j in i:N
+            p_sqrt *
+            (V[:, i] * transpose(V[:, j]) + V[:, j] * transpose(V[:, i])) *
+            p_sqrt for i in 1:N for j in i:N
     ]
     λ = eigv.values
     κ = [-1 / 4 * (λ[i] - λ[j])^2 for i in 1:N for j in i:N]
@@ -303,7 +303,7 @@ end
 
 Compute the inner product of `X`, `Y` in the tangent space of `p` on
 the [`SymmetricPositiveDefinite`](@ref) manifold `M`, as
-a [`MetricManifold`](@ref) with [`AffineInvariantMetric`](@ref). The formula reads
+a [`MetricManifold`](@extref ManifoldsBase.MetricManifold) with [`AffineInvariantMetric`](@ref). The formula reads
 
 ````math
 g_p(X,Y) = \operatorname{tr}(p^{-1} X p^{-1} Y),
@@ -320,14 +320,14 @@ end
 Return false. [`SymmetricPositiveDefinite`](@ref) with [`AffineInvariantMetric`](@ref)
 is not a flat manifold.
 """
-is_flat(M::MetricManifold{ℝ,<:SymmetricPositiveDefinite,AffineInvariantMetric}) = false
+is_flat(M::MetricManifold{ℝ, <:SymmetricPositiveDefinite, AffineInvariantMetric}) = false
 
 @doc raw"""
     log(M::SymmetricPositiveDefinite, p, q)
     log(M::MetricManifold{SymmetricPositiveDefinite,AffineInvariantMetric}, p, q)
 
 Compute the logarithmic map from `p` to `q` on the [`SymmetricPositiveDefinite`](@ref)
-as a [`MetricManifold`](@ref) with [`AffineInvariantMetric`](@ref). The formula reads
+as a [`MetricManifold`](@extref ManifoldsBase.MetricManifold) with [`AffineInvariantMetric`](@ref). The formula reads
 
 ```math
 \log_p q =
@@ -338,11 +338,11 @@ where ``\operatorname{Log}`` denotes to the matrix logarithm.
 log(::SymmetricPositiveDefinite, ::Any...)
 
 function allocate_result(
-    M::SymmetricPositiveDefinite,
-    ::typeof(log),
-    q::SPDPoint,
-    p::SPDPoint,
-)
+        M::SymmetricPositiveDefinite,
+        ::typeof(log),
+        q::SPDPoint,
+        p::SPDPoint,
+    )
     return allocate_result(M, log, convert(AbstractMatrix, q), convert(AbstractMatrix, p))
 end
 
@@ -368,7 +368,7 @@ manifold_volume(::SymmetricPositiveDefinite) = Inf
 
 Compute the parallel transport of `X` from the tangent space at `p` to the
 tangent space at `q` on the [`SymmetricPositiveDefinite`](@ref) as a
-[`MetricManifold`](@ref) with the [`AffineInvariantMetric`](@ref).
+[`MetricManifold`](@extref ManifoldsBase.MetricManifold) with the [`AffineInvariantMetric`](@ref).
 The formula reads
 
 ```math
