@@ -1,4 +1,3 @@
-
 _unit_weights(n::Int) = StatsBase.UnitWeights{Float64}(n)
 
 function Base.show(io::IO, method::GeodesicInterpolationWithinRadius)
@@ -33,37 +32,37 @@ Finally, the covariance matrix in the tangent plane is estimated using the Eucli
  [`CovarianceEstimation.jl`](https://github.com/mateuszbaran/CovarianceEstimation.jl/).
 """
 function Statistics.cov(
-    M::AbstractManifold,
-    x::AbstractVector;
-    basis::AbstractBasis=DefaultOrthonormalBasis(),
-    tangent_space_covariance_estimator::CovarianceEstimator=SimpleCovariance(;
-        corrected=true,
-    ),
-    mean_estimation_method::AbstractApproximationMethod=default_approximation_method(
-        M,
-        cov,
-    ),
-    inverse_retraction_method::AbstractInverseRetractionMethod=default_inverse_retraction_method(
-        M,
-        eltype(x),
-    ),
-)
+        M::AbstractManifold,
+        x::AbstractVector;
+        basis::AbstractBasis = DefaultOrthonormalBasis(),
+        tangent_space_covariance_estimator::CovarianceEstimator = SimpleCovariance(;
+            corrected = true,
+        ),
+        mean_estimation_method::AbstractApproximationMethod = default_approximation_method(
+            M,
+            cov,
+        ),
+        inverse_retraction_method::AbstractInverseRetractionMethod = default_inverse_retraction_method(
+            M,
+            eltype(x),
+        ),
+    )
     μ = mean(M, x, mean_estimation_method)
     Xs_at_μ = map(p -> inverse_retract(M, μ, p, inverse_retraction_method), x)
     Xcs = map(X -> get_coordinates(M, μ, X, basis), Xs_at_μ)
     return cov(
         tangent_space_covariance_estimator,
         reduce(hcat, Xcs);
-        mean=zero(Xcs[1]),
-        dims=2,
+        mean = zero(Xcs[1]),
+        dims = 2,
     )
 end
 
 function default_approximation_method(
-    ::EmptyTrait,
-    ::AbstractDecoratorManifold,
-    ::typeof(cov),
-)
+        ::StopForwardingType,
+        ::AbstractDecoratorManifold,
+        ::typeof(cov),
+    )
     return GradientDescentEstimation()
 end
 function default_approximation_method(::AbstractManifold, ::typeof(cov))
@@ -127,30 +126,30 @@ function Statistics.mean(M::AbstractManifold, x::AbstractVector, kwargs...)
     return mean(M, x, default_approximation_method(M, mean, eltype(x)); kwargs...)
 end
 function Statistics.mean(
-    M::AbstractManifold,
-    x::AbstractVector,
-    w::AbstractVector,
-    kwargs...,
-)
+        M::AbstractManifold,
+        x::AbstractVector,
+        w::AbstractVector,
+        kwargs...,
+    )
     return mean(M, x, w, default_approximation_method(M, mean, eltype(x)); kwargs...)
 end
 
 function Statistics.mean(
-    M::AbstractManifold,
-    x::AbstractVector,
-    method::AbstractApproximationMethod;
-    kwargs...,
-)
+        M::AbstractManifold,
+        x::AbstractVector,
+        method::AbstractApproximationMethod;
+        kwargs...,
+    )
     y = allocate_result(M, mean, x[1])
     return mean!(M, y, x, method; kwargs...)
 end
 function Statistics.mean(
-    M::AbstractManifold,
-    x::AbstractVector,
-    w::AbstractVector,
-    method::AbstractApproximationMethod;
-    kwargs...,
-)
+        M::AbstractManifold,
+        x::AbstractVector,
+        w::AbstractVector,
+        method::AbstractApproximationMethod;
+        kwargs...,
+    )
     y = allocate_result(M, mean, x[1])
     return mean!(M, y, x, w, method; kwargs...)
 end
@@ -171,30 +170,30 @@ Compute the [`mean`](@ref mean(::AbstractManifold, args...)) in-place in `y`.
 mean!(::AbstractManifold, ::Any...)
 
 function Statistics.mean!(
-    M::AbstractManifold,
-    y,
-    x::AbstractVector,
-    method::AbstractApproximationMethod=default_approximation_method(M, mean);
-    kwargs...,
-)
+        M::AbstractManifold,
+        y,
+        x::AbstractVector,
+        method::AbstractApproximationMethod = default_approximation_method(M, mean);
+        kwargs...,
+    )
     w = _unit_weights(length(x))
     return mean!(M, y, x, w, method; kwargs...)
 end
 function Statistics.mean!(
-    M::AbstractManifold,
-    y,
-    x::AbstractVector,
-    w::AbstractVector,
-    ::GradientDescentEstimation;
-    p0=x[1],
-    stop_iter=100,
-    retraction::AbstractRetractionMethod=default_retraction_method(M, eltype(x)),
-    inverse_retraction::AbstractInverseRetractionMethod=default_inverse_retraction_method(
-        M,
-        eltype(x),
-    ),
-    kwargs...,
-)
+        M::AbstractManifold,
+        y,
+        x::AbstractVector,
+        w::AbstractVector,
+        ::GradientDescentEstimation;
+        p0 = x[1],
+        stop_iter = 100,
+        retraction::AbstractRetractionMethod = default_retraction_method(M, eltype(x)),
+        inverse_retraction::AbstractInverseRetractionMethod = default_inverse_retraction_method(
+            M,
+            eltype(x),
+        ),
+        kwargs...,
+    )
     n = length(x)
     if length(w) != n
         throw(
@@ -248,27 +247,25 @@ the (inverse) retraction.
 mean(::AbstractManifold, ::AbstractVector, ::AbstractVector, ::GeodesicInterpolation)
 
 function Statistics.mean!(
-    M::AbstractManifold,
-    q,
-    x::AbstractVector,
-    w::AbstractVector,
-    ::GeodesicInterpolation;
-    shuffle_rng::Union{AbstractRNG,Nothing}=nothing,
-    retraction::AbstractRetractionMethod=default_retraction_method(M, eltype(x)),
-    inverse_retraction::AbstractInverseRetractionMethod=default_inverse_retraction_method(
-        M,
-        eltype(x),
-    ),
-    kwargs...,
-)
+        M::AbstractManifold,
+        q,
+        x::AbstractVector,
+        w::AbstractVector,
+        ::GeodesicInterpolation;
+        shuffle_rng::Union{AbstractRNG, Nothing} = nothing,
+        retraction::AbstractRetractionMethod = default_retraction_method(M, eltype(x)),
+        inverse_retraction::AbstractInverseRetractionMethod = default_inverse_retraction_method(
+            M,
+            eltype(x),
+        ),
+        kwargs...,
+    )
     n = length(x)
-    if length(w) != n
-        throw(
-            DimensionMismatch(
-                "The number of weights ($(length(w))) does not match the number of points for the mean ($(n)).",
-            ),
-        )
-    end
+    (length(w) != n) && throw(
+        DimensionMismatch(
+            "The number of weights ($(length(w))) does not match the number of points for the mean ($(n)).",
+        ),
+    )
     order = shuffle_rng === nothing ? (1:n) : shuffle(shuffle_rng, 1:n)
     @inbounds begin
         j = order[1]
@@ -312,39 +309,39 @@ Statistics.mean(
 )
 
 function Statistics.mean!(
-    M::AbstractManifold,
-    q,
-    x::AbstractVector,
-    w::AbstractVector,
-    method::GeodesicInterpolationWithinRadius;
-    shuffle_rng=nothing,
-    kwargs...,
-)
-    mean!(M, q, x, w, GeodesicInterpolation(); shuffle_rng=shuffle_rng, kwargs...)
+        M::AbstractManifold,
+        q,
+        x::AbstractVector,
+        w::AbstractVector,
+        method::GeodesicInterpolationWithinRadius;
+        shuffle_rng = nothing,
+        kwargs...,
+    )
+    mean!(M, q, x, w, GeodesicInterpolation(); shuffle_rng = shuffle_rng, kwargs...)
     radius = method.radius
     injectivity_radius(M, q) ≤ radius && return q
     for i in eachindex(x)
         @inbounds if distance(M, q, x[i]) ≥ radius
-            return mean!(M, q, x, w, GradientDescentEstimation(); p0=q, kwargs...)
+            return mean!(M, q, x, w, GradientDescentEstimation(); p0 = q, kwargs...)
         end
     end
     return q
 end
 function Statistics.mean!(
-    M::AbstractManifold,
-    q,
-    x::AbstractVector,
-    w::AbstractVector,
-    ::CyclicProximalPointEstimation;
-    p0=x[1],
-    stop_iter=1000000,
-    retraction::AbstractRetractionMethod=default_retraction_method(M, eltype(x)),
-    inverse_retraction::AbstractInverseRetractionMethod=default_inverse_retraction_method(
-        M,
-        eltype(x),
-    ),
-    kwargs...,
-)
+        M::AbstractManifold,
+        q,
+        x::AbstractVector,
+        w::AbstractVector,
+        ::CyclicProximalPointEstimation;
+        p0 = x[1],
+        stop_iter = 1000000,
+        retraction::AbstractRetractionMethod = default_retraction_method(M, eltype(x)),
+        inverse_retraction::AbstractInverseRetractionMethod = default_inverse_retraction_method(
+            M,
+            eltype(x),
+        ),
+        kwargs...,
+    )
     n = length(x)
     if length(w) != n
         throw(
@@ -396,20 +393,24 @@ Statistics.mean(
 )
 
 function Statistics.mean!(
-    M::AbstractManifold,
-    y,
-    x::AbstractVector,
-    w::AbstractVector,
-    e::ExtrinsicEstimation;
-    kwargs...,
-)
+        M::AbstractManifold,
+        y,
+        x::AbstractVector{P},
+        w::AbstractVector,
+        e::ExtrinsicEstimation;
+        kwargs...,
+    ) where {P}
     embedded_x = map(p -> embed(M, p), x)
-    embedded_y = mean(get_embedding(M), embedded_x, w, e.extrinsic_estimation; kwargs...)
+    embedded_y = mean(get_embedding(M, P), embedded_x, w, e.extrinsic_estimation; kwargs...)
     project!(M, y, embedded_y)
     return y
 end
 
-function default_approximation_method(::EmptyTrait, ::AbstractManifold, ::typeof(mean))
+function default_approximation_method(
+        ::StopForwardingType,
+        ::AbstractManifold,
+        ::typeof(mean),
+    )
     return GradientDescentEstimation()
 end;
 function default_approximation_method(::AbstractManifold, ::typeof(mean))
@@ -442,10 +443,10 @@ Compute the median using the specified `method`.
 Statistics.median(::AbstractManifold, ::Any...)
 
 function default_approximation_method(
-    ::EmptyTrait,
-    ::AbstractDecoratorManifold,
-    ::typeof(median),
-)
+        ::StopForwardingType,
+        ::AbstractDecoratorManifold,
+        ::typeof(median),
+    )
     return CyclicProximalPointEstimation()
 end
 function default_approximation_method(::AbstractManifold, ::typeof(median))
@@ -571,30 +572,30 @@ function Statistics.median(M::AbstractManifold, x::AbstractVector; kwargs...)
     return median(M, x, default_approximation_method(M, median, eltype(x)))
 end
 function Statistics.median(
-    M::AbstractManifold,
-    x::AbstractVector,
-    w::AbstractVector;
-    kwargs...,
-)
+        M::AbstractManifold,
+        x::AbstractVector,
+        w::AbstractVector;
+        kwargs...,
+    )
     return median(M, x, w, default_approximation_method(M, median, eltype(x)))
 end
 
 function Statistics.median(
-    M::AbstractManifold,
-    x::AbstractVector,
-    method::AbstractApproximationMethod;
-    kwargs...,
-)
+        M::AbstractManifold,
+        x::AbstractVector,
+        method::AbstractApproximationMethod;
+        kwargs...,
+    )
     y = allocate_result(M, median, x[1])
     return median!(M, y, x, method; kwargs...)
 end
 function Statistics.median(
-    M::AbstractManifold,
-    x::AbstractVector,
-    w::AbstractVector,
-    method::AbstractApproximationMethod;
-    kwargs...,
-)
+        M::AbstractManifold,
+        x::AbstractVector,
+        w::AbstractVector,
+        method::AbstractApproximationMethod;
+        kwargs...,
+    )
     y = allocate_result(M, median, x[1])
     return median!(M, y, x, w, method; kwargs...)
 end
@@ -614,30 +615,30 @@ computes the [`median`](@ref) in-place in `y`.
 """
 median!(::AbstractManifold, ::Any...)
 function Statistics.median!(
-    M::AbstractManifold,
-    q,
-    x::AbstractVector,
-    method::AbstractApproximationMethod=default_approximation_method(M, median, eltype(x));
-    kwargs...,
-)
+        M::AbstractManifold,
+        q,
+        x::AbstractVector,
+        method::AbstractApproximationMethod = default_approximation_method(M, median, eltype(x));
+        kwargs...,
+    )
     w = _unit_weights(length(x))
     return median!(M, q, x, w, method; kwargs...)
 end
 function Statistics.median!(
-    M::AbstractManifold,
-    q,
-    x::AbstractVector,
-    w::AbstractVector,
-    ::CyclicProximalPointEstimation;
-    p0=x[1],
-    stop_iter=1000000,
-    retraction::AbstractRetractionMethod=default_retraction_method(M, eltype(x)),
-    inverse_retraction::AbstractInverseRetractionMethod=default_inverse_retraction_method(
-        M,
-        eltype(x),
-    ),
-    kwargs...,
-)
+        M::AbstractManifold,
+        q,
+        x::AbstractVector,
+        w::AbstractVector,
+        ::CyclicProximalPointEstimation;
+        p0 = x[1],
+        stop_iter = 1000000,
+        retraction::AbstractRetractionMethod = default_retraction_method(M, eltype(x)),
+        inverse_retraction::AbstractInverseRetractionMethod = default_inverse_retraction_method(
+            M,
+            eltype(x),
+        ),
+        kwargs...,
+    )
     n = length(x)
     if length(w) != n
         throw(
@@ -666,35 +667,35 @@ function Statistics.median!(
 end
 
 function Statistics.median!(
-    M::AbstractManifold,
-    y,
-    x::AbstractVector,
-    w::AbstractVector,
-    e::ExtrinsicEstimation;
-    kwargs...,
-)
+        M::AbstractManifold,
+        y,
+        x::AbstractVector{P},
+        w::AbstractVector,
+        e::ExtrinsicEstimation;
+        kwargs...,
+    ) where {P}
     embedded_x = map(p -> embed(M, p), x)
-    embedded_y = median(get_embedding(M), embedded_x, w, e.extrinsic_estimation; kwargs...)
+    embedded_y = median(get_embedding(M, P), embedded_x, w, e.extrinsic_estimation; kwargs...)
     project!(M, y, embedded_y)
     return y
 end
 
 function Statistics.median!(
-    M::AbstractManifold,
-    q,
-    x::AbstractVector,
-    w::AbstractVector,
-    ::WeiszfeldEstimation;
-    p0=x[1],
-    stop_iter=2000,
-    α=1.0,
-    retraction::AbstractRetractionMethod=default_retraction_method(M, eltype(x)),
-    inverse_retraction::AbstractInverseRetractionMethod=default_inverse_retraction_method(
-        M,
-        eltype(x),
-    ),
-    kwargs...,
-)
+        M::AbstractManifold,
+        q,
+        x::AbstractVector,
+        w::AbstractVector,
+        ::WeiszfeldEstimation;
+        p0 = x[1],
+        stop_iter = 2000,
+        α = 1.0,
+        retraction::AbstractRetractionMethod = default_retraction_method(M, eltype(x)),
+        inverse_retraction::AbstractInverseRetractionMethod = default_inverse_retraction_method(
+            M,
+            eltype(x),
+        ),
+        kwargs...,
+    )
     n = length(x)
     if length(w) != n
         throw(
@@ -743,12 +744,12 @@ to the computation of the mean (if that is not provided).
 """
 var(::AbstractManifold, ::Any)
 function Statistics.var(
-    M::AbstractManifold,
-    x::AbstractVector,
-    w::AbstractWeights,
-    m;
-    corrected::Bool=false,
-)
+        M::AbstractManifold,
+        x::AbstractVector,
+        w::AbstractWeights,
+        m;
+        corrected::Bool = false,
+    )
     wv = convert(AbstractVector, w)
     s = sum(eachindex(x, w)) do i
         return @inbounds w[i] * distance(M, m, x[i])^2
@@ -756,17 +757,17 @@ function Statistics.var(
     c = StatsBase.varcorrection(w, corrected)
     return c * s
 end
-function Statistics.var(M::AbstractManifold, x::AbstractVector, m; corrected::Bool=true)
+function Statistics.var(M::AbstractManifold, x::AbstractVector, m; corrected::Bool = true)
     n = length(x)
     w = _unit_weights(n)
-    return var(M, x, w, m; corrected=corrected)
+    return var(M, x, w, m; corrected = corrected)
 end
 function Statistics.var(
-    M::AbstractManifold,
-    x::AbstractVector,
-    w::AbstractWeights;
-    kwargs...,
-)
+        M::AbstractManifold,
+        x::AbstractVector,
+        w::AbstractWeights;
+        kwargs...,
+    )
     return mean_and_var(M, x, w; kwargs...)[2]
 end
 function Statistics.var(M::AbstractManifold, x::AbstractVector; kwargs...)
@@ -810,37 +811,37 @@ a mean-specific method, call [`mean`](@ref mean(::AbstractManifold, args...)) an
 """
 mean_and_var(M::AbstractManifold, ::Any...)
 function StatsBase.mean_and_var(
-    M::AbstractManifold,
-    x::AbstractVector,
-    w::AbstractWeights,
-    method::AbstractApproximationMethod=default_approximation_method(M, mean, eltype(x));
-    corrected=false,
-    kwargs...,
-)
+        M::AbstractManifold,
+        x::AbstractVector,
+        w::AbstractWeights,
+        method::AbstractApproximationMethod = default_approximation_method(M, mean, eltype(x));
+        corrected = false,
+        kwargs...,
+    )
     m = mean(M, x, w, method; kwargs...)
-    v = var(M, x, w, m; corrected=corrected)
+    v = var(M, x, w, m; corrected = corrected)
     return m, v
 end
 function StatsBase.mean_and_var(
-    M::AbstractManifold,
-    x::AbstractVector,
-    method::AbstractApproximationMethod=default_approximation_method(
-        M,
-        mean_and_var,
-        eltype(x),
-    );
-    corrected=true,
-    kwargs...,
-)
+        M::AbstractManifold,
+        x::AbstractVector,
+        method::AbstractApproximationMethod = default_approximation_method(
+            M,
+            mean_and_var,
+            eltype(x),
+        );
+        corrected = true,
+        kwargs...,
+    )
     n = length(x)
     w = _unit_weights(n)
-    return mean_and_var(M, x, w, method; corrected=corrected, kwargs...)
+    return mean_and_var(M, x, w, method; corrected = corrected, kwargs...)
 end
 function default_approximation_method(
-    ::EmptyTrait,
-    M::AbstractDecoratorManifold,
-    ::typeof(mean_and_var),
-)
+        ::StopForwardingType,
+        M::AbstractDecoratorManifold,
+        ::typeof(mean_and_var),
+    )
     return default_approximation_method(M, mean)
 end
 function default_approximation_method(M::AbstractManifold, ::typeof(mean_and_var))
@@ -874,19 +875,19 @@ interpolation method.
     to give accurate results except on [`Euclidean`](@ref).
 """
 function StatsBase.mean_and_var(
-    M::AbstractManifold,
-    x::AbstractVector,
-    w::AbstractWeights,
-    ::GeodesicInterpolation;
-    shuffle_rng::Union{AbstractRNG,Nothing}=nothing,
-    corrected=false,
-    retraction::AbstractRetractionMethod=default_retraction_method(M, eltype(x)),
-    inverse_retraction::AbstractInverseRetractionMethod=default_inverse_retraction_method(
-        M,
-        eltype(x),
-    ),
-    kwargs...,
-)
+        M::AbstractManifold,
+        x::AbstractVector,
+        w::AbstractWeights,
+        ::GeodesicInterpolation;
+        shuffle_rng::Union{AbstractRNG, Nothing} = nothing,
+        corrected = false,
+        retraction::AbstractRetractionMethod = default_retraction_method(M, eltype(x)),
+        inverse_retraction::AbstractInverseRetractionMethod = default_inverse_retraction_method(
+            M,
+            eltype(x),
+        ),
+        kwargs...,
+    )
     n = length(x)
     if length(w) != n
         throw(
@@ -937,29 +938,29 @@ See [`GeodesicInterpolationWithinRadius`](@extref `ManifoldsBase.GeodesicInterpo
 for more information.
 """
 function StatsBase.mean_and_var(
-    M::AbstractManifold,
-    x::AbstractVector,
-    w::AbstractWeights,
-    method::GeodesicInterpolationWithinRadius;
-    shuffle_rng=nothing,
-    corrected=false,
-    kwargs...,
-)
+        M::AbstractManifold,
+        x::AbstractVector,
+        w::AbstractWeights,
+        method::GeodesicInterpolationWithinRadius;
+        shuffle_rng = nothing,
+        corrected = false,
+        kwargs...,
+    )
     y, v = mean_and_var(
         M,
         x,
         w,
         GeodesicInterpolation();
-        shuffle_rng=shuffle_rng,
-        corrected=corrected,
+        shuffle_rng = shuffle_rng,
+        corrected = corrected,
         kwargs...,
     )
     radius = method.radius
     injectivity_radius(M, y) ≤ radius && return y, v
     for i in eachindex(x)
         @inbounds if distance(M, y, x[i]) ≥ radius
-            mean!(M, y, x, w, GradientDescentEstimation(); p0=y, kwargs...)
-            v = var(M, x, w, y; corrected=corrected)
+            mean!(M, y, x, w, GradientDescentEstimation(); p0 = y, kwargs...)
+            v = var(M, x, w, y; corrected = corrected)
             return y, v
         end
     end
@@ -1000,18 +1001,18 @@ provide weights `w` and/or a precomputed
 [`mean`](@ref mean(::AbstractManifold, args...)).
 """
 function StatsBase.moment(
-    M::AbstractManifold,
-    x::AbstractVector,
-    k::Int,
-    w::AbstractWeights,
-    m=mean(M, x, w),
-)
+        M::AbstractManifold,
+        x::AbstractVector,
+        k::Int,
+        w::AbstractWeights,
+        m = mean(M, x, w),
+    )
     s = sum(eachindex(x, w)) do i
         return @inbounds w[i] * distance(M, m, x[i])^k
     end
     return s / sum(w)
 end
-function StatsBase.moment(M::AbstractManifold, x::AbstractVector, k::Int, m=mean(M, x))
+function StatsBase.moment(M::AbstractManifold, x::AbstractVector, k::Int, m = mean(M, x))
     w = _unit_weights(length(x))
     return moment(M, x, k, w, m)
 end
@@ -1024,11 +1025,11 @@ provide weights `w` and/or a precomputed
 [`mean`](@ref mean(::AbstractManifold, args...)) `m`.
 """
 function StatsBase.skewness(M::AbstractManifold, x::AbstractVector, w::AbstractWeights)
-    m, s = mean_and_std(M, x, w; corrected=false)
+    m, s = mean_and_std(M, x, w; corrected = false)
     return moment(M, x, 3, w, m) / s^3
 end
 function StatsBase.skewness(M::AbstractManifold, x::AbstractVector, w::AbstractWeights, m)
-    return moment(M, x, 3, w, m) / std(M, x, w, m; corrected=false)^3
+    return moment(M, x, 3, w, m) / std(M, x, w, m; corrected = false)^3
 end
 function StatsBase.skewness(M::AbstractManifold, x::AbstractVector, args...)
     w = _unit_weights(length(x))
@@ -1043,34 +1044,42 @@ provide weights `w` and/or a precomputed
 [`mean`](@ref mean(::AbstractManifold, args...)) `m`.
 """
 function StatsBase.kurtosis(M::AbstractManifold, x::AbstractVector, w::AbstractWeights)
-    m, v = mean_and_var(M, x, w; corrected=false)
+    m, v = mean_and_var(M, x, w; corrected = false)
     return moment(M, x, 4, w, m) / v^2 - 3
 end
 function StatsBase.kurtosis(M::AbstractManifold, x::AbstractVector, w::AbstractWeights, m)
-    return moment(M, x, 4, w, m) / var(M, x, w, m; corrected=false)^2 - 3
+    return moment(M, x, 4, w, m) / var(M, x, w, m; corrected = false)^2 - 3
 end
 function StatsBase.kurtosis(M::AbstractManifold, x::AbstractVector, args...)
     w = _unit_weights(length(x))
     return kurtosis(M, x, w, args...)
 end
 
-#
-# decorate default method for a few functions
 for mf in [mean, median, cov, var, mean_and_std, mean_and_var]
     @eval @trait_function default_approximation_method(
         M::AbstractDecoratorManifold,
         f::typeof($mf),
-    ) (no_empty,)
+    )
     eval(
         quote
-            function default_approximation_method(
-                ::TraitList{IsEmbeddedSubmanifold},
-                M::AbstractDecoratorManifold,
-                f::typeof($mf),
-            )
-                return default_approximation_method(get_embedding(M), f)
+            function ManifoldsBase.get_forwarding_type_embedding(
+                    ::ManifoldsBase.EmbeddedSubmanifoldType{ManifoldsBase.DirectEmbedding},
+                    M::AbstractDecoratorManifold, ::typeof($mf),
+                )
+                return ManifoldsBase.EmbeddedForwardingType()
+            end
+            function ManifoldsBase.get_forwarding_type_embedding(
+                    ::ManifoldsBase.EmbeddedSubmanifoldType{ManifoldsBase.IndirectEmbedding},
+                    M::AbstractDecoratorManifold, ::typeof($mf),
+                )
+                return ManifoldsBase.EmbeddedForwardingType(ManifoldsBase.DirectEmbedding())
             end
         end,
     )
 end
+
+#
+# decorate default method for a few functions
+# TODO: Check how to “ask” the embedding for default approx methods, when it exists,
+# for the functions [mean, median, cov, var, mean_and_std, mean_and_var]
 @trait_function Statistics.mean(M::AbstractDecoratorManifold, x::AbstractVector)
