@@ -1,13 +1,7 @@
-
-TEST_FLOAT32 = get(ENV, "MANIFOLDS_TEST_FLOAT32", false)
-TEST_DOUBLE64 = get(ENV, "MANIFOLDS_TEST_FLOAT64", false)
-TEST_STATIC_SIZED = get(ENV, "MANIFOLDS_TEST_STATIC_SIZED", false)
-TEST_GROUP = get(ENV, "MANIFOLDS_TEST_GROUP", "all")
-
+# TODO: Remove as soon as all manifolds moved to the new test suite.
 using Manifolds
 using ManifoldsBase
 using ManifoldsBase: number_of_coordinates, TypeParameter
-import ManifoldsBase: active_traits, merge_traits
 
 using ManifoldDiff
 
